==> ktp-text-ui-16.11.80.tar.xz: ktp-text-ui-16.11.80/filters/geopoint/ktptextui_message_filter_geopoint.desktop.cmake <==
[Desktop Entry]
Encoding=UTF-8
Type=Service
ServiceTypes=KTpTextUi/MessageFilter

X-KDE-Library=ktptextui_message_filter_geopoint
X-KDE-PluginInfo-Author=Alexandr Akulich
X-KDE-PluginInfo-Email=akulichalexander@gmail.com
X-KDE-PluginInfo-Name=geopoint
X-KDE-PluginInfo-Version=@KTP_TEXT_UI_VERSION@
X-KDE-PluginInfo-Website=http://community.kde.org/KTp
X-KDE-PluginInfo-License=GPL
X-KDE-PluginInfo-EnabledByDefault=false
X-KTp-PluginInfo-Version=@KTP_MESSAGE_FILTER_FRAMEWORK_VERSION@

Name=Geopoint Preview
Name[ca]=Vista prèvia del punt geogràfic
Name[ca@valencia]=Vista prèvia del punt geogràfic
Name[en_GB]=Geopoint Preview
Name[es]=Vista previa de punto geográfico
Name[et]=Geopunkti eelvaatlus
Name[fi]=Sijainnin esikatselu
Name[it]=Anteprima di punto geografico
Name[nl]=Voorbeeld van geo-punt
Name[nn]=Geopunkt-førehandsvising
Name[pl]=Podgląd geopunktu
Name[pt]=Antevisão de Ponto Geográfico
Name[sk]=Náhľad Geopoint
Name[sl]=Predogled Geopoint
Name[sv]=Förhandsgranskning av geografisk punkt
Name[uk]=Перегляд геоточки
Name[x-test]=xxGeopoint Previewxx
Name[zh_CN]=地理位置预览
Name[zh_TW]=Geopoint 預覽
Comment=Show geo URI on a map view.
Comment[ca]=Mostra la URI geogràfica a la vista d'un mapa.
Comment[ca@valencia]=Mostra la URI geogràfica a la vista d'un mapa.
Comment[en_GB]=Show geo URI on a map view.
Comment[es]=Mostrar un URI geográfico en un visor de mapa.
Comment[et]=Geo-URI näitamine kaardil
Comment[fi]=Näytä sijainnin URI karttanäkymässä.
Comment[it]=Mostra l'URI geografico su una mappa.
Comment[nl]=Geo-URI op een kaart tonen.
Comment[nn]=Vis geoadresser på kartvising.
Comment[pl]=Pokaż URI geo w widoku mapy.
Comment[pt]=Mostrar um URI geográfico num mapa.
Comment[sk]=Zobraziť geo URI na pohľade mapy.
Comment[sl]=Pokaži geo URI na prikazu zemljevida.
Comment[sv]=Visa geografisk webbadress i en kartvy.
Comment[uk]=Показувати геоадресу на перегляді карти.
Comment[x-test]=xxShow geo URI on a map view.xx
Comment[zh_CN]=在地图视图上显示地理 URI。
Comment[zh_TW]=顯示在地圖檢示上顯示 geo URI。

==> ktp-text-ui-16.11.90.tar.xz: ktp-text-ui-16.11.90/filters/geopoint/ktptextui_message_filter_geopoint.desktop.cmake <==
[Desktop Entry]
Encoding=UTF-8
Type=Service
ServiceTypes=KTpTextUi/MessageFilter

X-KDE-Library=ktptextui_message_filter_geopoint
X-KDE-PluginInfo-Author=Alexandr Akulich
X-KDE-PluginInfo-Email=akulichalexander@gmail.com
X-KDE-PluginInfo-Name=geopoint
X-KDE-PluginInfo-Version=@KTP_TEXT_UI_VERSION@
X-KDE-PluginInfo-Website=http://community.kde.org/KTp
X-KDE-PluginInfo-License=GPL
X-KDE-PluginInfo-EnabledByDefault=false
X-KTp-PluginInfo-Version=@KTP_MESSAGE_FILTER_FRAMEWORK_VERSION@

Name=Geopoint Preview
Name[ca]=Vista prèvia del punt geogràfic
Name[ca@valencia]=Vista prèvia del punt geogràfic
Name[en_GB]=Geopoint Preview
Name[es]=Vista previa de punto geográfico
Name[et]=Geopunkti eelvaatlus
Name[fi]=Sijainnin esikatselu
Name[it]=Anteprima di punto geografico
Name[nl]=Voorbeeld van geo-punt
Name[nn]=Geopunkt-førehandsvising
Name[pl]=Podgląd geopunktu
Name[pt]=Antevisão de Ponto Geográfico
Name[sk]=Náhľad Geopoint
Name[sl]=Predogled Geopoint
Name[sr]=Преглед географске тачке
Name[sr@ijekavian]=Преглед географске тачке
Name[sr@ijekavianlatin]=Pregled geografske tačke
Name[sr@latin]=Pregled geografske tačke
Name[sv]=Förhandsgranskning av geografisk punkt
Name[uk]=Перегляд геоточки
Name[x-test]=xxGeopoint Previewxx
Name[zh_CN]=地理位置预览
Name[zh_TW]=Geopoint 預覽
Comment=Show geo URI on a map view.
Comment[ca]=Mostra la URI geogràfica a la vista d'un mapa.
Comment[ca@valencia]=Mostra la URI geogràfica a la vista d'un mapa.
Comment[en_GB]=Show geo URI on a map view.
Comment[es]=Mostrar un URI geográfico en un visor de mapa.
Comment[et]=Geo-URI näitamine kaardil
Comment[fi]=Näytä sijainnin URI karttanäkymässä.
Comment[it]=Mostra l'URI geografico su una mappa.
Comment[nl]=Geo-URI op een kaart tonen.
Comment[nn]=Vis geoadresser på kartvising.
Comment[pl]=Pokaż URI geo w widoku mapy.
Comment[pt]=Mostrar um URI geográfico num mapa.
Comment[sk]=Zobraziť geo URI na pohľade mapy.
Comment[sl]=Pokaži geo URI na prikazu zemljevida.
Comment[sr]=Приказивање географског УРИ‑ја на карти
Comment[sr@ijekavian]=Приказивање географског УРИ‑ја на карти
Comment[sr@ijekavianlatin]=Prikazivanje geografskog URI‑ja na karti
Comment[sr@latin]=Prikazivanje geografskog URI‑ja na karti
Comment[sv]=Visa geografisk webbadress i en kartvy.
Comment[uk]=Показувати геоадресу на перегляді карти.
Comment[x-test]=xxShow geo URI on a map view.xx
Comment[zh_CN]=在地图视图上显示地理 URI。
Comment[zh_TW]=顯示在地圖檢示上顯示 geo URI。
